==> haskell-shake-0.16.4-99-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-shake.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shake
version: 0.16.4
id: shake-0.16.4-I6ycOTqfALLAcSN7CQjWpD
key: shake-0.16.4-I6ycOTqfALLAcSN7CQjWpD
license: BSD-3-Clause
copyright: Neil Mitchell 2011-2018
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://shakebuild.com
synopsis: Build system library, like Make, but more accurate dependencies.
description:
    Shake is a Haskell library for writing build systems - designed as a
    replacement for @make@. See "Development.Shake" for an introduction,
    including an example. The homepage contains links to a user
    manual, an academic paper and further information:
    <https://shakebuild.com>
    .
    To use Shake the user writes a Haskell program
    that imports "Development.Shake", defines some build rules, and calls
    the '\''Development.Shake.shakeArgs'\'' function. Thanks to do notation and infix
    operators, a simple Shake build system
    is not too dissimilar from a simple Makefile. However, as build systems
    get more complex, Shake is able to take advantage of the excellent
    abstraction facilities offered by Haskell and easily support much larger
    projects. The Shake library provides all the standard features available in other
    build systems, including automatic parallelism and minimal rebuilds.
    Shake also provides more accurate dependency tracking, including seamless
    support for generated files, and dependencies on system information
    (e.g. compiler version).
category: Development, Shake
abi: 095bbdf2aea9109445735d45558f107f
exposed: True
exposed-modules:
    Development.Shake Development.Shake.Classes
    Development.Shake.Command Development.Shake.Config
    Development.Shake.FilePath Development.Shake.Forward
    Development.Shake.Rule Development.Shake.Util
hidden-modules: Development.Ninja.Env Development.Ninja.Lexer
                Development.Ninja.Parse Development.Ninja.Type
                Development.Shake.Internal.Args
                Development.Shake.Internal.CmdOption
                Development.Shake.Internal.Core.Action
                Development.Shake.Internal.Core.Database
                Development.Shake.Internal.Core.Monad
                Development.Shake.Internal.Core.Pool
                Development.Shake.Internal.Core.Rendezvous
                Development.Shake.Internal.Core.Rules
                Development.Shake.Internal.Core.Run
                Development.Shake.Internal.Core.Storage
                Development.Shake.Internal.Core.Types
                Development.Shake.Internal.Demo Development.Shake.Internal.Derived
                Development.Shake.Internal.Errors
                Development.Shake.Internal.FileInfo
                Development.Shake.Internal.FileName
                Development.Shake.Internal.FilePattern
                Development.Shake.Internal.Options Development.Shake.Internal.Paths
                Development.Shake.Internal.Profile
                Development.Shake.Internal.Progress
                Development.Shake.Internal.Resource
                Development.Shake.Internal.Rules.Directory
                Development.Shake.Internal.Rules.File
                Development.Shake.Internal.Rules.Files
                Development.Shake.Internal.Rules.Oracle
                Development.Shake.Internal.Rules.OrderOnly
                Development.Shake.Internal.Rules.Rerun
                Development.Shake.Internal.Shake Development.Shake.Internal.Value
                General.Bag General.Bilist General.Binary General.Chunks
                General.Cleanup General.Concurrent General.Extra General.FileLock
                General.GetOpt General.Ids General.Intern General.ListBuilder
                General.Makefile General.Process General.Template General.Timing
                Paths_shake
import-dirs: /usr/lib/ghc-8.4.3/site-local/shake-0.16.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/shake-0.16.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-shake
hs-libraries: HSshake-0.16.4-I6ycOTqfALLAcSN7CQjWpD
depends:
    base-4.11.1.0 binary-0.8.5.1 bytestring-0.10.8.2 deepseq-1.4.3.0
    directory-1.3.1.5 extra-1.6.12-DHdLvf94bhcHifO5HapwCI
    filepath-1.4.2 hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    js-flot-0.8.3-Bsjxmw7L5o0BiJSkgBCarQ
    js-jquery-3.3.1-3T2qpjRC85lJ95sMvYMxm7
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc process-1.6.3.0
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV time-1.8.0.2 transformers-0.5.5.0
    unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8 unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             extra-1.6.12-DHdLvf94bhcHifO5HapwCI=36b397877b0e54ac8d0c415a92aec365
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             js-flot-0.8.3-Bsjxmw7L5o0BiJSkgBCarQ=22192e8eaba4308c5317363c4da3caab
             js-jquery-3.3.1-3T2qpjRC85lJ95sMvYMxm7=70b96c8d4818b66266f3e43a388df40f
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre=264f905ec4c04eb05b5ff3d7321fae90
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-shake/html/shake.haddock
haddock-html: /usr/share/doc/haskell-shake/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shake-0.16.4-100-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-shake.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shake
version: 0.16.4
id: shake-0.16.4-CVEQGo014T58upT0Q2Qahn
key: shake-0.16.4-CVEQGo014T58upT0Q2Qahn
license: BSD-3-Clause
copyright: Neil Mitchell 2011-2018
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://shakebuild.com
synopsis: Build system library, like Make, but more accurate dependencies.
description:
    Shake is a Haskell library for writing build systems - designed as a
    replacement for @make@. See "Development.Shake" for an introduction,
    including an example. The homepage contains links to a user
    manual, an academic paper and further information:
    <https://shakebuild.com>
    .
    To use Shake the user writes a Haskell program
    that imports "Development.Shake", defines some build rules, and calls
    the '\''Development.Shake.shakeArgs'\'' function. Thanks to do notation and infix
    operators, a simple Shake build system
    is not too dissimilar from a simple Makefile. However, as build systems
    get more complex, Shake is able to take advantage of the excellent
    abstraction facilities offered by Haskell and easily support much larger
    projects. The Shake library provides all the standard features available in other
    build systems, including automatic parallelism and minimal rebuilds.
    Shake also provides more accurate dependency tracking, including seamless
    support for generated files, and dependencies on system information
    (e.g. compiler version).
category: Development, Shake
abi: e9f34afaf3b51166a02b068c8a2bd8ac
exposed: True
exposed-modules:
    Development.Shake Development.Shake.Classes
    Development.Shake.Command Development.Shake.Config
    Development.Shake.FilePath Development.Shake.Forward
    Development.Shake.Rule Development.Shake.Util
hidden-modules: Development.Ninja.Env Development.Ninja.Lexer
                Development.Ninja.Parse Development.Ninja.Type
                Development.Shake.Internal.Args
                Development.Shake.Internal.CmdOption
                Development.Shake.Internal.Core.Action
                Development.Shake.Internal.Core.Database
                Development.Shake.Internal.Core.Monad
                Development.Shake.Internal.Core.Pool
                Development.Shake.Internal.Core.Rendezvous
                Development.Shake.Internal.Core.Rules
                Development.Shake.Internal.Core.Run
                Development.Shake.Internal.Core.Storage
                Development.Shake.Internal.Core.Types
                Development.Shake.Internal.Demo Development.Shake.Internal.Derived
                Development.Shake.Internal.Errors
                Development.Shake.Internal.FileInfo
                Development.Shake.Internal.FileName
                Development.Shake.Internal.FilePattern
                Development.Shake.Internal.Options Development.Shake.Internal.Paths
                Development.Shake.Internal.Profile
                Development.Shake.Internal.Progress
                Development.Shake.Internal.Resource
                Development.Shake.Internal.Rules.Directory
                Development.Shake.Internal.Rules.File
                Development.Shake.Internal.Rules.Files
                Development.Shake.Internal.Rules.Oracle
                Development.Shake.Internal.Rules.OrderOnly
                Development.Shake.Internal.Rules.Rerun
                Development.Shake.Internal.Shake Development.Shake.Internal.Value
                General.Bag General.Bilist General.Binary General.Chunks
                General.Cleanup General.Concurrent General.Extra General.FileLock
                General.GetOpt General.Ids General.Intern General.ListBuilder
                General.Makefile General.Process General.Template General.Timing
                Paths_shake
import-dirs: /usr/lib/ghc-8.4.3/site-local/shake-0.16.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/shake-0.16.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-shake
hs-libraries: HSshake-0.16.4-CVEQGo014T58upT0Q2Qahn
depends:
    base-4.11.1.0 binary-0.8.5.1 bytestring-0.10.8.2 deepseq-1.4.3.0
    directory-1.3.1.5 extra-1.6.12-DHdLvf94bhcHifO5HapwCI
    filepath-1.4.2 hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    js-flot-0.8.3-Bsjxmw7L5o0BiJSkgBCarQ
    js-jquery-3.3.1-H8hne2vcfOF8zl8RsGabrc
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc process-1.6.3.0
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV time-1.8.0.2 transformers-0.5.5.0
    unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8 unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             extra-1.6.12-DHdLvf94bhcHifO5HapwCI=36b397877b0e54ac8d0c415a92aec365
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             js-flot-0.8.3-Bsjxmw7L5o0BiJSkgBCarQ=22192e8eaba4308c5317363c4da3caab
             js-jquery-3.3.1-H8hne2vcfOF8zl8RsGabrc=e0680810f9bd9144be522724f2d58003
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre=264f905ec4c04eb05b5ff3d7321fae90
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-shake/html/shake.haddock
haddock-html: /usr/share/doc/haskell-shake/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
